@@ -25,16 +25,22 @@
 #include "gupnp-dlna-gst-image-information.h"
 #include "gupnp-dlna-gst-info-utils.h"
 
-G_DEFINE_TYPE (GUPnPDLNAGstImageInformation,
-               gupnp_dlna_gst_image_information,
-               GUPNP_TYPE_DLNA_IMAGE_INFORMATION)
-
 struct _GUPnPDLNAGstImageInformationPrivate {
         GstDiscovererInfo *info;
         GList *stream_list;
         GstDiscovererVideoInfo *image_info;
         GstCaps *caps;
 };
+typedef struct _GUPnPDLNAGstImageInformationPrivate
+        GUPnPDLNAGstImageInformationPrivate;
+
+struct _GUPnPDLNAGstImageInformation {
+        GUPnPDLNAImageInformation parent;
+};
+
+G_DEFINE_TYPE_WITH_PRIVATE (GUPnPDLNAGstImageInformation,
+                            gupnp_dlna_gst_image_information,
+                            GUPNP_TYPE_DLNA_IMAGE_INFORMATION)
 
 enum
 {
@@ -46,7 +52,9 @@ enum
 static GstDiscovererVideoInfo *
 get_image_info (GUPnPDLNAGstImageInformation *gst_info)
 {
-        GUPnPDLNAGstImageInformationPrivate *priv = gst_info->priv;
+        GUPnPDLNAGstImageInformationPrivate *priv =
+                gupnp_dlna_gst_image_information_get_instance_private (
+                        gst_info);
 
         if (!priv->image_info) {
                 GList *iter;
@@ -78,7 +86,9 @@ get_image_info (GUPnPDLNAGstImageInformation *gst_info)
 static GstCaps *
 get_caps (GUPnPDLNAGstImageInformation *gst_info)
 {
-        GUPnPDLNAGstImageInformationPrivate *priv = gst_info->priv;
+        GUPnPDLNAGstImageInformationPrivate *priv =
+                gupnp_dlna_gst_image_information_get_instance_private (
+                        gst_info);
 
         if (!priv->caps)
                 priv->caps = gst_discoverer_stream_info_get_caps
@@ -153,7 +163,8 @@ gupnp_dlna_gst_image_information_dispose (GObject *object)
 {
         GUPnPDLNAGstImageInformation *info =
                                       GUPNP_DLNA_GST_IMAGE_INFORMATION (object);
-        GUPnPDLNAGstImageInformationPrivate *priv = info->priv;
+        GUPnPDLNAGstImageInformationPrivate *priv =
+                gupnp_dlna_gst_image_information_get_instance_private (info);
         GObjectClass *parent_class =
                  G_OBJECT_CLASS (gupnp_dlna_gst_image_information_parent_class);
         g_clear_pointer (&priv->info, gupnp_dlna_gst_discoverer_info_unref);
@@ -173,7 +184,8 @@ gupnp_dlna_gst_image_information_set_property (GObject      *object,
 {
         GUPnPDLNAGstImageInformation *info =
                                       GUPNP_DLNA_GST_IMAGE_INFORMATION (object);
-        GUPnPDLNAGstImageInformationPrivate *priv = info->priv;
+        GUPnPDLNAGstImageInformationPrivate *priv =
+                gupnp_dlna_gst_image_information_get_instance_private (info);
 
         switch (property_id) {
         case PROP_INFO:
@@ -197,7 +209,8 @@ gupnp_dlna_gst_image_information_get_property (GObject    *object,
 {
         GUPnPDLNAGstImageInformation *info =
                                       GUPNP_DLNA_GST_IMAGE_INFORMATION (object);
-        GUPnPDLNAGstImageInformationPrivate *priv = info->priv;
+        GUPnPDLNAGstImageInformationPrivate *priv =
+                gupnp_dlna_gst_image_information_get_instance_private (info);
 
         switch (property_id) {
         case PROP_INFO:
@@ -239,24 +252,11 @@ gupnp_dlna_gst_image_information_class_init
         g_object_class_install_property (object_class,
                                          PROP_INFO,
                                          pspec);
-
-        g_type_class_add_private (gst_info_class,
-                                  sizeof (GUPnPDLNAGstImageInformationPrivate));
 }
 
 static void
 gupnp_dlna_gst_image_information_init (GUPnPDLNAGstImageInformation *self)
 {
-        GUPnPDLNAGstImageInformationPrivate *priv = G_TYPE_INSTANCE_GET_PRIVATE
-                                        (self,
-                                         GUPNP_TYPE_DLNA_GST_IMAGE_INFORMATION,
-                                         GUPnPDLNAGstImageInformationPrivate);
-
-        priv->info = NULL;
-        priv->stream_list = NULL;
-        priv->image_info = NULL;
-        priv->caps = NULL;
-        self->priv = priv;
 }
 
 GUPnPDLNAGstImageInformation *
