@@ -26,19 +26,37 @@
 #include "gupnp-dlna-gst-information.h"
 #include "gupnp-dlna-gst-utils.h"
 
+typedef struct _GUPnPDLNAGstMetadataExtractorPrivate
+        GUPnPDLNAGstMetadataExtractorPrivate;
+
+/**
+ * GUPnPDLNAGstMetadataExtractor:
+ *
+ * The top-level object used to for metadata extraction.
+ */
+struct _GUPnPDLNAGstMetadataExtractor {
+        GUPnPDLNAMetadataExtractor parent;
+
+        GUPnPDLNAGstMetadataExtractorPrivate *priv;
+};
+// Backwards-compatible defines
+/**
+ * GUPNP_IS_DLNA_GST_METADATA_BACKEND: (skip)
+ */
+#define GUPNP_IS_GST_DLNA_METADATA_BACKEND GUPNP_DLNA_IS_GST_METADATA_BACKEND
+/**
+ * GUPNP_IS_GST_DLNA_METADATA_BACKEND_CLASS: (skip)
+ */
+#define GUPNP_IS_GST_DLNA_METADATA_BACKEND_CLASS GUPNP_DLNA_IS_GST_METADATA_BACKEND_CLASS
+
 G_DEFINE_TYPE (GUPnPDLNAGstMetadataExtractor,
                gupnp_dlna_gst_metadata_extractor,
                GUPNP_TYPE_DLNA_METADATA_EXTRACTOR)
 
-struct _GUPnPDLNAGstMetadataExtractorPrivate {
-        gpointer placeholder;
-};
-
 static gboolean
 unref_discoverer_in_idle (GstDiscoverer *discoverer)
 {
-        if (discoverer)
-                g_object_unref (discoverer);
+        g_clear_object (&discoverer);
 
         return FALSE;
 }
@@ -137,21 +155,11 @@ gupnp_dlna_gst_metadata_extractor_class_init
 
         extractor_class->extract_async = backend_extract_async;
         extractor_class->extract_sync = backend_extract_sync;
-
-        g_type_class_add_private
-                                (gst_extractor_class,
-                                 sizeof (GUPnPDLNAGstMetadataExtractorPrivate));
 }
 
 static void
 gupnp_dlna_gst_metadata_extractor_init (GUPnPDLNAGstMetadataExtractor *self)
 {
-        GUPnPDLNAGstMetadataExtractorPrivate *priv =
-            G_TYPE_INSTANCE_GET_PRIVATE (self,
-                                         GUPNP_TYPE_DLNA_GST_METADATA_EXTRACTOR,
-                                         GUPnPDLNAGstMetadataExtractorPrivate);
-
-        self->priv = priv;
 }
 
 GUPnPDLNAGstMetadataExtractor *
