@@ -246,10 +246,6 @@ main (int argc,
 
         GOptionContext *ctx;
 
-#if !GLIB_CHECK_VERSION(2,35,0)
-        g_type_init ();
-#endif
-
         setlocale (LC_ALL, "");
 
         ctx = g_option_context_new (" - program to extract DLNA and related metadata");
