@@ -39,7 +39,7 @@
 static gboolean relaxed = FALSE;
 
 static void
-print_profile (GUPnPDLNAProfile *profile)
+print_profile (GUPnPDLNAProfile *profile, gpointer user_data)
 {
         g_print ("%s %-30s%-35s\n",
                  gupnp_dlna_profile_get_extended (profile) ? "*" : " ",
@@ -62,10 +62,6 @@ main (int argc, char **argv)
 
         GOptionContext *ctx;
 
-#if !GLIB_CHECK_VERSION(2,35,0)
-        g_type_init ();
-#endif
-
         setlocale (LC_ALL, "");
 
         ctx = g_option_context_new (" - program to list all the DLNA profiles supported by gupnp-dlna");
